summaryrefslogtreecommitdiff
path: root/libpod/runtime_pod.go
diff options
context:
space:
mode:
Diffstat (limited to 'libpod/runtime_pod.go')
-rw-r--r--libpod/runtime_pod.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/libpod/runtime_pod.go b/libpod/runtime_pod.go
index 0debb7924..3619a7a82 100644
--- a/libpod/runtime_pod.go
+++ b/libpod/runtime_pod.go
@@ -162,11 +162,11 @@ func (r *Runtime) RemovePod(p *Pod, removeCtrs, force bool) error {
return err
}
// Delete the container from runc (only if we are not
// ContainerStateConfigured)
if ctr.state.State != ContainerStateConfigured {
if err := r.ociRuntime.deleteContainer(ctr); err != nil {
- return errors.Wrapf(err, "error removing container %s from runc", ctr.ID())
+ return errors.Wrapf(err, "error removing container %s from runtime", ctr.ID())
}
}
@@ -162,11 +162,11 @@ func (r *Runtime) RemovePod(p *Pod, removeCtrs, force bool) error {
return err
}
- // Delete the container from runc (only if we are not
+ // Delete the container from runtime (only if we are not
// ContainerStateConfigured)
if ctr.state.State != ContainerStateConfigured {